==> beacon_0_1_1.tar.tgz: beacon/beacon/index.php <==
<?php

include_once "inc/header.inc.php";


//SETUP COMMENT -------------------------------------------------------------
require_once($c_node['dir']['class_path'] . 'Comment.class.php');
$comment = new Comment($db, $date);

if (isset($_POST['preview_comment'])) {
	$output_comment = $frmdata;
	$output_comment['comment_body'] = stripslashes($output_comment['comment_body']);
	$output_comment['display_comment_body'] = nl2br(htmlspecialchars($output_comment["comment_body"], ENT_QUOTES));
	$output_comment['comment_body'] = str_replace ('"', '&quot;', $output_comment['comment_body']);

	$display = "preview_comment";

}
elseif (isset($_POST['insert_comment'])) {
	$comment->user_id = $_SESSION['user_id'];
	$comment->insertComment($frmdata);

	if (empty($GLOBALS['beacon_error_log'])) {
		return header("Location: index.php?item_id=". $frmdata['item_id'] . "&" . SID);
		exit;
	}
}
elseif (isset($_POST['edit_comment_again'])) {
	$output_comment = $frmdata;
	$output_comment['comment_body'] = stripslashes($output_comment['comment_body']);
}







// GET ITEM
$output_item = $item->selItem();


if (isset($output_item['item_id'])) {
	
	$pages = $item->selPages();
	$wiki->setRenderConf('xhtml', 'wikilink', 'pages', $pages);
	
	$output_item['item_body_display'] = $wiki->transform($output_item['item_body'], 'Xhtml');
	
	$comment->item_id = $output_item['item_id'];
	$output_comments = $comment->selComments();
}




//TEMPLATE
if (!empty($output_item)) {
	$body->set('item', $output_item);
}

if (!empty($output_comments)) {
	$body->set('comments', $output_comments);
}

if (!empty($output_comment)) {
	$body->set('comment', $output_comment);
}
if (!empty($display)) {
	$body->set('display', $display);
}

include "inc/footer.inc.php";
?>

==> beacon_0_1_5.tar.tgz: beacon/beacon/index.php <==
<?php

include_once "inc/header.inc.php";


//SETUP COMMENT -------------------------------------------------------------
require_once($c_node['dir']['class_path'] . 'Comment.class.php');
$comment = new Comment($db, $date);

if (isset($_POST['preview_comment'])) {
	$output_comment = $frmdata;
	$output_comment['comment_body'] = stripslashes($output_comment['comment_body']);
	$output_comment['display_comment_body'] = nl2br(htmlspecialchars($output_comment["comment_body"], ENT_QUOTES));
	$output_comment['comment_body'] = str_replace ('"', '&quot;', $output_comment['comment_body']);

	$display = "preview_comment";

}
elseif (isset($_POST['insert_comment'])) {
	$comment->user_id = $_SESSION['user_id'];
	$comment->insertComment($frmdata);

	if (empty($GLOBALS['beacon_error_log'])) {
		return header("Location: index.php?item_id=". $frmdata['item_id'] . "&" . SID);
		exit;
	}
}
elseif (isset($_POST['edit_comment_again'])) {
	$output_comment = $frmdata;
	$output_comment['comment_body'] = stripslashes($output_comment['comment_body']);
}




// GET ITEM
$output_item = $item->selItem();


if (isset($output_item['item_id'])) {
	
	$pages = $item->selWikiPageNames();
	
	$wiki->setRenderConf('xhtml', 'wikilink', 'pages', $pages);
	
	$output_item['item_body_display'] = $wiki->transform($output_item['item_body'], 'Xhtml');
	
	$comment->item_id = $output_item['item_id'];
	
	if (isset($_REQUEST['ico'])) { //item comments only
		$output_comments = $comment->selComments();
	}
	else {
		$output_comments = $comment->selComments(null, $output_item['wiki_page']);
	}
	// if not the lastest version include link to it.
	if ($output_item['item_id'] != $output_item['current_item_id']) {
		$lang['arr_error'][13] = str_replace("WIKIPAGE", $output_item['wiki_page'], $lang['arr_error'][13]);
		$GLOBALS['beacon_error_log'][] = array(13, null);
	}
}




//TEMPLATE
if (!empty($output_item)) {
	$body->set('item', $output_item);
}

if (!empty($output_comments)) {
	$body->set('comments', $output_comments);
}

if (!empty($output_comment)) {
	$body->set('comment', $output_comment);
}
if (!empty($display)) {
	$body->set('display', $display);
}

include "inc/footer.inc.php";
?>
